<?php
/**
 * @var $key
 * @var $tip
 * @var $active
 */

defined( 'ABSPATH' ) || exit;

if ( empty( $key ) ) {
	$key = uniqid( 'wpcot-' );
}

$tip_name   = ( isset( $tip['name'] ) && ! empty( $tip['name'] ) ) ? esc_html( $tip['name'] ) : esc_html__( 'Default', 'wpc-order-tip' );
$tip_desc   = ( isset( $tip['desc'] ) && ! empty( $tip['desc'] ) ) ? esc_html( $tip['desc'] ) : '';
$tip_custom = ( isset( $tip['custom'] ) && ! empty( $tip['custom'] ) ) ? esc_attr( $tip['custom'] ) : 'no';
$tip_min    = ( isset( $tip['custom_min'] ) && ! empty( $tip['custom_min'] ) ) ? (float) $tip['custom_min'] : '';
$tip_max    = ( isset( $tip['custom_max'] ) && ! empty( $tip['custom_max'] ) ) ? (float) $tip['custom_max'] : '';
$tip_step   = ( isset( $tip['custom_step'] ) && ! empty( $tip['custom_step'] ) ) ? (float) $tip['custom_step'] : '';
$tip_value  = ( isset( $tip['custom_value'] ) && ! empty( $tip['custom_value'] ) ) ? (float) $tip['custom_value'] : '';
$tip_roles  = ( isset( $tip['roles'] ) && is_array( $tip['roles'] ) && ! empty( $tip['roles'] ) ) ? $tip['roles'] : array( 'wpcot_all' );
?>
<div class="<?php echo esc_attr( $active ? 'wpcot-tip active' : 'wpcot-tip' ); ?>">
    <div class="wpcot-tip-header">
        <span class="wpcot-tip-move ui-sortable-handle"><?php esc_html_e( 'move', 'wpc-order-tip' ); ?></span>
        <span class="wpcot-tip-label"><?php echo esc_html( $tip_name ); ?></span>
        <span class="wpcot-remove-tip"><?php esc_html_e( 'remove', 'wpc-order-tip' ); ?></span>
    </div>
    <div class="wpcot-tip-content">
        <div class="wpcot-tip-line">
            <label><?php esc_html_e( 'Name *', 'wpc-order-tip' ); ?></label>
            <div class="input-panel">
                <input type="text" value="<?php echo esc_attr( $tip_name ); ?>" class="wpcot-tip-name input-block"
                       name="wpcot_tips[<?php echo esc_attr( $key ); ?>][name]" required/>
            </div>
        </div>
        <div class="wpcot-tip-line">
            <label><?php esc_html_e( 'Description', 'wpc-order-tip' ); ?></label>
            <div class="input-panel">
                <textarea class="input-block"
                          name="wpcot_tips[<?php echo esc_attr( $key ); ?>][desc]"><?php echo esc_html( $tip_desc ); ?></textarea>
            </div>
        </div>
        <div class="wpcot-tip-line">
            <label><?php esc_html_e( 'Values', 'wpc-order-tip' ); ?></label>
            <div class="wpcot-values-wrap">
                <div class="wpcot-values">
					<?php
					$count = 0;

					if ( isset( $tip['values'] ) && is_array( $tip['values'] ) && ! empty( $tip['values'] ) ) {
						foreach ( $tip['values'] as $value ) { ?>
                            <div class="wpcot-value input-panel">
                    <span class="wpcot-label-wrapper">
                        <input type="text" value="<?php echo esc_attr( $value['label'] ); ?>"
                               placeholder="<?php esc_attr_e( 'label', 'wpc-order-tip' ); ?>"
                               name="wpcot_tips[<?php echo esc_attr( $key ); ?>][values][<?php echo esc_attr( $count ); ?>][label]"/>
                        </span>
                                <span class="wpcot-value-wrapper hint--top"
                                      aria-label="<?php esc_attr_e( 'Set a value using a number (eg. "10") or percentage (eg. "15%" of order subtotal)', 'wpc-order-tip' ); ?>">
                        <input type="text" value="<?php echo esc_attr( $value['value'] ); ?>"
                               placeholder="<?php esc_attr_e( 'value', 'wpc-order-tip' ); ?>"
                               name="wpcot_tips[<?php echo esc_attr( $key ); ?>][values][<?php echo esc_attr( $count ); ?>][value]"/>
                    </span>
                                <span class="wpcot-remove-value hint--top"
                                      aria-label="<?php esc_attr_e( 'remove', 'wpc-order-tip' ); ?>">&times;</span>
                            </div>
							<?php
							$count ++;
						}
					} ?>
                </div>
                <div class="wpcot-new-value">
                    <button class="button wpcot-add-value" type="button" data-key="<?php echo esc_attr( $key ); ?>"
                            data-count="<?php echo esc_attr( $count ); ?>">
						<?php esc_html_e( '+ New value', 'wpc-order-tip' ); ?>
                    </button>
                </div>
            </div>
        </div>
        <div class="wpcot-tip-line">
            <label><?php esc_html_e( 'Custom amount', 'wpc-order-tip' ); ?></label>
            <div class="input-panel">
                <select name="wpcot_tips[<?php echo esc_attr( $key ); ?>][custom]" class="wpcot-custom">
                    <option value="no" <?php selected( $tip_custom, 'no' ); ?>><?php esc_html_e( 'No', 'wpc-order-tip' ); ?></option>
                    <option value="yes" <?php selected( $tip_custom, 'yes' ); ?>><?php esc_html_e( 'Yes', 'wpc-order-tip' ); ?></option>
                </select>
                <div class="wpcot-show-if-custom">
                    <span class="hint--top" aria-label="<?php esc_attr_e( 'min', 'wpc-order-tip' ); ?>">
                        <input type="number" name="wpcot_tips[<?php echo esc_attr( $key ); ?>][custom_min]"
                               value="<?php echo esc_attr( $tip_min ); ?>"
                               placeholder="<?php esc_attr_e( 'min', 'wpc-order-tip' ); ?>"/>
                    </span>
                    <span class="hint--top" aria-label="<?php esc_attr_e( 'step', 'wpc-order-tip' ); ?>">
                        <input type="number" name="wpcot_tips[<?php echo esc_attr( $key ); ?>][custom_step]"
                               value="<?php echo esc_attr( $tip_step ); ?>"
                               placeholder="<?php esc_attr_e( 'step', 'wpc-order-tip' ); ?>"/>
                    </span>
                    <span class="hint--top" aria-label="<?php esc_attr_e( 'max', 'wpc-order-tip' ); ?>">
                        <input type="number" name="wpcot_tips[<?php echo esc_attr( $key ); ?>][custom_max]"
                               value="<?php echo esc_attr( $tip_max ); ?>"
                               placeholder="<?php esc_attr_e( 'max', 'wpc-order-tip' ); ?>"/>
                    </span>
                    <span class="hint--top" aria-label="<?php esc_attr_e( 'default value', 'wpc-order-tip' ); ?>">
                        <input type="number" name="wpcot_tips[<?php echo esc_attr( $key ); ?>][custom_value]"
                               value="<?php echo esc_attr( $tip_value ); ?>"
                               placeholder="<?php esc_attr_e( 'default value', 'wpc-order-tip' ); ?>"/>
                    </span>
                </div>
            </div>
        </div>
        <div class="wpcot-tip-line">
            <label><?php esc_html_e( 'User role', 'wpc-order-tip' ); ?></label>
            <div class="input-panel">
                <select name="wpcot_tips[<?php echo esc_attr( $key ); ?>][roles][]" multiple style="height: 200px"
                        disabled>
					<?php
					global $wp_roles;


					echo '<option value="wpcot_all" ' . ( in_array( 'wpcot_all', $tip_roles ) ? 'selected' : '' ) . '>' . esc_html__( 'All', 'wpc-order-tip' ) . '</option>';

					foreach ( $wp_roles->roles as $role => $details ) {
						echo '<option value="' . esc_attr( $role ) . '" ' . ( in_array( $role, $tip_roles ) ? 'selected' : '' ) . '>' . esc_html( $details['name'] ) . '</option>';
					}
					?>
                </select>
                <span class="description"><?php esc_html_e( 'Select which user role that can see this tip group. Hold down the Ctrl (or Command) button to select multiple options.', 'wpc-order-tip' ); ?></span>
                <span class="description"
                      style="color: #c9356e"><?php esc_html_e( 'This feature is only available on the Premium Version.', 'wpc-order-tip' ); ?></span>
            </div>
        </div>
    </div>
</div>
